      program tileselect

c ---------------------------------------------------------------------
c
c --- TILESELECT    Version: V3.0       Level: 090929                 MAIN
c
c     Copyright (c) 2009 by Exponent, Inc.
c
c --- Purpose:
C     Select tiles needed for mm5decode to create 3D.DAT files
c 
c --- Zhong-Xiang Wu
C     Developed: 6/12/2008

C --- Changes From Version: 2.0  Level: 090509 to Version: V3.0  Level: 090929
C  1. Add Tiled Data Version and level numbers on tile configuration file 
C  2. Add Timestamp on tile configuration and description files
C  3. Add option to create a batch file to rename tile files
C  4. Add computer OS control for rename tile files
C
C --- Changes From Version: 1.5  Level: 090327 to Version: 2.0  Level: 090509
C  1. Use configuration file to replace all header files

C --- Changes from Version: V1.4 Level: 081013 to Version: V1.5 Level: 090327
C  1. Add all regions included in mm5decode V2.6

C --- Changes from Version: V1.3 Level: 080930 to Version: V1.4 Level: 081013
C  1. Add Australia, New Zealand, Saudi_2001)

C --- Changes from Version: V1.2 Level: 080905 to Version: V1.3 Level: 080930
C  1. Expand  0.25 degree if no grids can be found within 
C     user-specified domain (Only coded for lon/lat-select option)
C  2. Add output grid lat/lon to list file if id_grid set to 1.
C  3. Add four regions (Peru, Middle East, China, Thailand)

C --- Changes from Version: V1.1 Level: 080807 to Version: V1.2 Level: 080905
C  1 Change tile setup for later MM5 packing in following way:
C    i. 10 x 10 grids for internal tiles
C   ii. For last row and column:  The maximum size for 10 x 10 grids tiles
C       in 495.2 MB from MM5EU-2006 tiles. The size limit of one tile
C       is 750 MB.  Therefore the maximum grids holding by one tile
C       is 150 grids
C       a. Equal to, or less than, 50 grids, merge to next inner tiles
C       b. More than 50 grids, separate tiles themselves
C  2. This code still accept previous tile configuration for the four 
C     previous MM5 runs (EUD2-2006/2007, SAMS_D2, SAMN_D2) 
C     1. Add Japan and South Africa regions to packed tile datasets
C
C --- Zhong-Xiang Wu
C     9/5/2008
C --- Changes from Version: V1.0 Level: 080612 to Version: V1.1 Level: 080807
C     1. Add three more packed tile datasets
C
C --- Zhong-Xiang Wu
C     8/7/2008
  
      include 'tileselect.par'
      include 'tileselect.cm1'

c----------------------------------------------------------------------
c
c --- Set Code Version and Level number of code
      cver='3.0'
      clevel='090929'

c --- Open control file with user input information
      fct='tileselect.inp'
      call comline(fct)
      open(ict,file=fct,status='old')
c
c --- Read title line from control file
      read(ict,101)title_inp
 101  format(a)

c --- Read output list file name 
      read(ict,101)flog
      nt=index(flog,' ')-1
      flog=flog(1:nt)

c --- Open list file
      open(ilog,file=flog,status='unknown')

c --- Write version and level number of code to list file and
c     echo back control file inputs
      write(ilog,301)cver,clevel
 301  format(1x,'Tileselect -- Version: ',a16,' Level: ',a16//)

      write(ilog,302)title_inp
 302  format(1x,'Title: ',a80)
      write(ilog,303)flog
 303  format(/1x,'List file name: ',a80)

c --- Read output file name
      read(ict,101)fou
      ntfou=index(fou,' ')-1
      fou=fou(1:ntfou)
      write(ilog,305)fou(1:ntfou)
 305  format(/1x,'Output file: ',a)

c --- Open output file
      open(io,file=fou,status='unknown')

      read(ict,*)id_reg

c --- Read/write method of selecting domain 
C     (1= I/J; 2=long/lat; 3=center lon/lat and range)
      read(ict,*)iselect
      write(ilog,306)iselect
306   format(/1x,'Method for selecting domain: ',i6,/,5x,
     1 ' (1=I/J; 2=lon/lat; 3: center lon/lat & range)')

      if(iselect.eq.1) then
         read(ict,*)ibeg,iend
         read(ict,*)jbeg,jend
         write(ilog,*)ibeg,iend,jbeg,jend
      else if(iselect.eq.2)then
         read(ict,*)flonbeg,flonend
         read(ict,*)flatbeg,flatend
         write(ilog,*)flonbeg,flonend,flatbeg,flatend
      else if(iselect.eq.3)then
         read(ict,*)flonc,flatc
         read(ict,*)rkm
         write(ilog,*)flonc,flatc,rkm
      else
         write(ilog,314)iselect
         print 314,iselect
 314     format(1x,'Error - Selection method must be:',/,5x,
     &      ' 1-(I/J), 2-(long/lat), 3-(center&range)',/,
     &      1x,'Invalid selection method for defining domain: ',i4/)
         stop
      endif

C --- Flag to create batch job to rename tile files
      read(ict,*)id_bat
      if(id_bat.eq.1) then
         read(ict,101)fbat
         nt=index(fbat,' ')-1
         fbat=fbat(1:nt)
         write(ilog,315)fbat(1:nt)
 315     format(/1x,'Batch file: ',a)

         read(ict,*)iway
         read(ict,*)ios
         write(ilog,*)' iway/ios:',iway,ios

         if(ios.eq.1) then
            cmove='move'
         else
            cmove='mv'
         endif

         open(ibat,file=fbat,status='unknown')         
      endif

      close(ict)
C --- Finish reading control file

C --- Configure mm5 domain
      call configmm5

      write(ilog,361)id_reg,trim(tiledes)
 361  format(' MM5 Region: ',i2,2x,a)

C --- Determine requested domain
      call getdmn
      
C --- Determine which tiles are needed
C     Figure out I/Js for this tile - South -> North; then West -> East 
      do i=1,ncx     ! I/J for all tiles
         i1=ni1+(i-1)*igrd
         i2=i1+igrd-1
         if(i.eq.ncx) i2=ni2

         do j=1,ncy
            icd=(i-1)*ncy+j
            j1=nj1+(j-1)*jgrd
            j2=j1+jgrd-1
            if(j.eq.ncy) j2=nj2

            ijcd(1,i,j)=i1
            ijcd(2,i,j)=i2
            ijcd(3,i,j)=j1
            ijcd(4,i,j)=j2

c            write(ilog,102)icd,i,j,i1,i2,j1,j2
c            print 102,icd,i,j,i1,i2,j1,j2
c 102        format('Tile-',i3.3,10i6)
        enddo
      enddo

      do i=1,ncx  ! columns needed
         i1=ijcd(1,i,1)
         i2=ijcd(2,i,1)

         if(ibeg.ge.i1 .and. ibeg.le.i2) icd_i1=i
         if(iend.ge.i1 .and. iend.le.i2) icd_i2=i
      enddo

      do j=1,ncy  ! rows needed
         j1=ijcd(3,1,j)
         j2=ijcd(4,1,j)

         if(jbeg.ge.j1 .and. jbeg.le.j2) icd_j1=j
         if(jend.ge.j1 .and. jend.le.j2) icd_j2=j
      enddo

      write(io,301)cver,clevel
      write(ilog,327)
      write(io,327)
327   format(1x,'Tiles needed for selected domain'/
     1 1x,' No.',2x,'Tile #',5x,'I/J Ranges on Tile',5x,
     2 'I/J Ranges Selected')
 
      nyrep=icd_j2-icd_j1+1
      nxrep=icd_i2-icd_i1+1

      ncd=0
      imi=999
      imx=-999
      jmi=999
      jmx=-999

      do i=icd_i1,icd_i2
        do j=icd_j1,icd_j2               
            icd=(i-1)*ncy+j
            ncd=ncd+1
            ncdpk(ncd)=icd  ! CD order #

c           I/J ranges needed on these CDs
            i1=ijcd(1,i,j)
            i2=ijcd(2,i,j)
            j1=ijcd(3,i,j)
            j2=ijcd(4,i,j)

            ijcdpk(1,ncd)=i1   ! I beg on this CD
            ijcdpk(2,ncd)=i2   ! I end on this CD
            ijcdpk(3,ncd)=j1   ! J beg on this CD
            ijcdpk(4,ncd)=j2   ! J end on this CD

            if(i1.le.imi) imi=i1
            if(i2.ge.imx) imx=i2
            if(j1.le.jmi) jmi=j1
            if(j2.ge.jmx) jmx=j2

            if(i1.lt.ibeg) i1=ibeg
            if(i2.gt.iend) i2=iend
            if(j1.lt.jbeg) j1=jbeg
            if(j2.gt.jend) j2=jend

            ijcdpk(5,ncd)=i1   ! picked I beg on this CD
            ijcdpk(6,ncd)=i2   ! picked I end on this CD
            ijcdpk(7,ncd)=j1   ! picked J beg on this CD
            ijcdpk(8,ncd)=j2   ! picked J end on this CD

            write(*,328)ncd,ncdpk(ncd),(ijcdpk(ii,ncd),ii=1,8)
            write(ilog,328)ncd,ncdpk(ncd),(ijcdpk(ii,ncd),ii=1,8)
            write(io,328)ncd,ncdpk(ncd),(ijcdpk(ii,ncd),ii=1,8)
 328        format(1x,i3,4x,i3.3,4x,4i5,3x,4i5)

            if(id_bat.eq.1) then
               nn=ncdpk(ncd)
               if(iway.eq.1) then
                  write(ibat,frmt)nn,trim(tilekey),nn
               else
                  write(ibat,frmt)trim(tilekey),nn,nn
               endif
            endif
         enddo
      enddo

      write(io,329)ncd
      write(ilog,329)ncd
      print 329,ncd
 329  format(/1x,'Total Number of tiles needed: ',i6)

      write(io,339)imi,imx,jmi,jmx
      write(ilog,339)imi,imx,jmi,jmx
 339  format(/1x,'I/J ranges on all needed CDs: ',4i4)

      write(ilog,*)' TileSelect Succeeded: 99999'
      print *,' TileSelect Succeeded: 99999'

      close(io)
      close(ilog)
      if(id_bat.eq.1) close(ibat)

      stop
      end

      include 'tileselect.blk'
      include 'calutils.for'
      include 'coordlib.for'

C --------------------------------------------------------------------
      Subroutine configmm5

c --- TILESELECT    Version: 3.0      Level: 090512               

C Purpose:
C    Get configuration information
C
C Zhong-Xiang Wu
C 5/12/2009

      parameter(iecho=1)

      include 'tileselect.par'
      include 'tileselect.cm1'

      character*300 buff1,buff2,buff3

C --- Open three configuration files
      open(ifg,file=fcfg,status='old',action='read')  ! MM5 config

C --- QA check for config files
      call lastup(ifg,cvercfg,clvlcfg,lastupdate)

C --- Skip two line
      read(ifg,*)ncom
      do i=1,ncom
         read(ifg,*)
      enddo

      read(ifg,101)header1
 101  format(a)

C --- Read tile configuration part
 1000 continue
      read(ifg,101)buff1
      read(buff1,*)id

C --- Find the region needed
C --- Domain Info
      if(id.eq.id_reg) then

         read(buff1,301)id,cmap,rlatch,rlonch,truelat1h,truelat2h,
     &        x1dmn,y1dmn,dxy,nx,ny,nz,nx1,ny1,nx2,ny2,nz1,nz2,
     &        rxmin,rxmax,rymin,rymax
 301     format(i3.3,1x,a4,f9.4,f10.4,2f7.2,2f10.3,f8.3,2i4,i3,6i4
     &       ,2f10.4,2f9.4)
         read(buff1(9:),*)(cfg(i),i=1,nas)

C ---     Fix an truelat1 bug in calmm5 version 2.12 and before for PST proj.
C         for Greenland runs
         if(id.ge.33 .and .id.le.35) then
            cfg(3)=rlatch
            truelat1h=rlatch
            cmap="PS  "
         endif

         write(ilog,'(a)')trim(header1)
         write(ilog,301)id,cmap,rlatch,rlonch,truelat1h,truelat2h,
     &        x1dmn,y1dmn,dxy,nx,ny,nz,nx1,ny1,nx2,ny2,nz1,nz2,
     &        rxmin,rxmax,rymin,rymax
      endif

      if(id.ne.idend) goto 1000

C --- Read Tile name and description part
      read(ifg,*)  ! skip on sub_title line

 2000 continue
      read(ifg,101)buff1
      read(buff1,*)id

C --- Find the region needed
C --- Domain Info
      if(id.eq.id_reg) then
         read(buff1(5:),'(a60)')tilekey
         read(buff1(65:),'(a)')tiledes
         write(ilog,311)trim(tilekey)
         print 311,trim(tilekey)
         write(ilog,312)trim(tiledes)
         print 312,trim(tiledes)
 311     format(' Tile Naming:       ',a)
 312     format(' Model Description: ',a)
         goto 3000
      endif

      if(id.ne.idend) goto 2000

 3000 continue

C --- Tile Configuration for entire domain
      ni2=nx2
      nj2=ny2

      nxd=ni2-ni1+1
      nyd=nj2-nj1+1

      ncx=nxd/igrd   ! Number of CD in I dir.
      ncy=nyd/jgrd   ! Number of CD in J dir.

C --- Earlier packing for Europe_D2 (2006/2007), Chile/Argentina, Northern SA 
C     use old tile configuration (may have narrow tiles in last column/row)
      if(id_reg.le.3) then
         if(mod(nxd,igrd).ne.0) ncx=nxd/igrd+1
         if(mod(nyd,jgrd).ne.0) ncy=nyd/jgrd+1      
      else
C ---    Later packing used new tile configuration (no narrow tiles 
C        in last column/row)
         modx=mod(nxd,igrd)
         mody=mod(nyd,jgrd)
         
         modx=modx*jgrd
         mody=mody*igrd

         if(modx.gt.modc) ncx=ncx+1
         if(mody.gt.modc) ncy=ncy+1
      endif

      ncdtot=ncx*ncy
      if(ncdtot.lt.1000) then
         ndig=3
      elseif(ncdtot.lt.10000) then
         ndig=4
      else
         print *,' Error: Tiles exceed 10000'
         stop
      endif

      if(iway.eq.1) then
         write(frmt,211)trim(cmove),ndig,ndig,ndig,ndig
 211     format("('",a,1x," Tile',i",i1,'.',i1,",'.pck ',",
     &        "a,'_Tile',i",i1,'.',i1,",'.pck')" )
      elseif(iway.eq.2) then
         write(frmt,212)trim(cmove),ndig,ndig,ndig,ndig
 212     format("('",a," ',a,'_Tile',i",i1,'.',i1,",'.pck ',",
     &        "'Tile',i",i1,'.',i1,",'.pck')" )
      else
         print *,' Error: Illegal iway: iway'
         stop
      endif

      write(ilog,201)ni1,ni2,nj1,nj2,ncx,ncy,ncdtot
      write(*,201)ni1,ni2,nj1,nj2,ncx,ncy,ncdtot
 201  format('ni1,ni2,nj1,nj2,ncx,ncy,ncdtot=',8i6)

      if(nx1.gt.ni1 .or. ny1.gt.nj1) then
         write(ilog,202)nx1,ny1,ni1,nj1
         write(*,101)nx1,ny1,ni1,nj1
 202     format(' Error: nx1/ny1 > ni1,nj1 - ',4i5)
         stop
      endif

      close(ifg)

      return
      end

C ---------------------------------------------------------------
      Subroutine getdmn

c --- TILESELECT    Version: 3.0      Level: 090512               

C Purpose:
C    Determine requested domain
C
C Zhong-Xiang Wu
C 5/12/2009

      parameter(iecho=1)

      include 'tileselect.par'
      include 'tileselect.cm1'

C --- QA check for user inputs
      flonb=rxmin
      flone=rxmax
      flatb=rymin
      flate=rymax

      if(iselect.eq.1) then
         write(ilog,351)
 351     format(/1x,'Using I/J to select a region')
         write(ilog,*)' Required I/J Ranges:',ibeg,iend,jbeg,jend
         if(ibeg.gt.iend) then
            write(ilog,308)ibeg,iend
 308        format(/1x,'ERROR -- Beginning I > ending I -- IBEG: ',i6,
     1      1x,'IEND: ',i6)
            print *,errmes
            stop
         endif
         if(jbeg.gt.jend) then
            write(ilog,309)jbeg,jend
 309        format(/1x,'ERROR -- Beginning J > ending J -- JBEG: ',i6,
     1      1x,'JEND: ',i6)
            print *,errmes
            stop
         endif

         if(ibeg.lt.nx1 .or. iend.gt.nx2) then
            write(ilog,307)nx1,nx2,ibeg,iend
            write(*,307)nx1,nx2,ibeg,iend
 307        format(1x,'Error: I - Outrange: MM5 ranges: ',2i4,
     &           /,1x,'           Reguired: ',2i4)
            stop
         endif
         if(jbeg.lt.ny1 .or. jend.gt.ny2) then
            write(ilog,3071)ny1,ny2,jbeg,jend
            write(*,3071)ny1,ny2,jbeg,jend
 3071       format(1x,'Error: J - Outrange: MM5 ranges: ',2i4,
     &           /,1x,'           Reguired: ',2i4)
            stop
         endif
      elseif(iselect.eq.2)then
         write(ilog,311)
 311     format(/1x,'Using Beginning/Ending longtiudes/latitudes '
     1   'to select a region'/
     2   1x,'(Negative longitude for Western Hemisphere)/')

         write(ilog,312)flonbeg,flonend
 312     format(1x,'Seleted longitude range: ',f8.3,2x,f8.3)
         write(ilog,313)flatbeg,flatend
 313     format(1x,'Seleted latitude range: ',f8.3,2x,f8.3)

         if(flonbeg.lt.flonb .or. flonend.gt.flone .or.
     &      flatbeg.lt.flatb .or. flatend.gt.flate) then
            write(ilog,342)flonbeg,flonend,flatbeg,flatend
     &                    ,flonb,flone,flatb,flate
            write(*,342)flonbeg,flonend,flatbeg,flatend
     &                    ,flonb,flone,flatb,flate
 342        format(' Error ----- Lon/Lat Out-Ranges: ',/,
     &             ' Requested:  ',4f12.4,/,' Data Range: ',4f12.4)

            stop
         endif

      elseif(iselect.eq.3) then
         write(ilog,343)
 343     format(/1x,'Using Center longtiudes/latitudes and range '
     1   'to select a region'/
     2   1x,'(Negative longitude for Western Hemisphere)/')


         if(flonc.lt.flonb .or. flonc.gt.flone .or.
     &      flatc.lt.flatb .or. flatc.gt.flate) then
            write(ilog,344)flonc,flatc
     &                    ,flonb,flone,flatb,flate
            write(*,344)flonc,flatc
     &                    ,flonb,flone,flatb,flate
 344        format(' Error --Center Lon/Lat Out-Ranges: ',/,
     &             ' Requested:  ',2f12.4,/,' Data Range: ',4f12.4)
            stop
         endif
      else
         write(ilog,314)iselect
         print 314,iselect
 314     format(1x,'Error - Selection method must be:',/,5x,
     &      ' 1-(I/J), 2-(long/lat), 3-(center&range)',/,
     &      1x,'Invalid selection method for defining domain: ',i4/)
         stop
      endif

      if(iselect.eq.1) goto 1000

C --- Convert lat/lon to X/Y for select3/3

c --- Initialize GLOBE1
      cmapi='LL'
      iutmi=999.9
      tmsone=1.0
      rlat1i=cfg(3)  
      rlat2i=cfg(4)
      rlat0i=cfg(1)
      rlon0i=cfg(2)
      feasti = 0.
      fnorti = 0.
      
      cmapo=cmap
      iutmo=999.9
      tmsone=1.0
      rlat1=cfg(3)
      rlat2=cfg(4)
      rlat0=cfg(1)
      rlon0=cfg(2)
      feasto = 0.
      fnorto = 0.

c --  Set conversion vectors
      call GLOBE1(
     &  cmapi,iutmi,tmsone,rlat1i,rlat2i,rlat0i,rlon0i,feasti,fnorti,
     &  cmapo,iutmo,tmsone,rlat1,rlat2,rlat0,rlon0,feasto,fnorto,
     &  caction,vecti,vecto)

c --- Convert station coordinates to model map projection and datm,
c     Translate coordinates 
      datumi='WGS-84  '
      datumo='NWS-84  '

      if(iselect.eq.2) then
         call GLOBE(ilog,caction,datumi,vecti,datumo,vecto,
     &        flonbeg,flatbeg,xbeg,ybeg,iutmo,c4hem)
         call GLOBE(ilog,caction,datumi,vecti,datumo,vecto,
     &        flonend,flatend,xend,yend,iutmo,c4hem)
         write(ilog,*)'Extraction range converted from Lon/Lat to X/Y-'
         write(ilog,*)' Beg/End Lat (deg): ',flatbeg, flatend
         write(ilog,*)' Beg/End Lon (deg): ',flonbeg, flonend
         write(ilog,*)' Beg/End X (km): ',xbeg,xend
         write(ilog,*)' Beg/End Y (km): ',ybeg,yend
      elseif(iselect.eq.3) then
         call GLOBE(ilog,caction,datumi,vecti,datumo,vecto,
     &        flonc,flatc,xc,yc,iutmo,c4hem)
         xbeg=xc-rkm
         xend=xc+rkm
         ybeg=yc-rkm
         yend=yc+rkm
         write(ilog,*)'Extraction range converted from Lon/Lat to X/Y-'
         write(ilog,*)' Center Lat/Lon (deg): ',flonc, flatc
         write(ilog,*)' Radius (km):          ',rkm
         write(ilog,*)' Beg/End X (km): ',xbeg,xend
         write(ilog,*)' Beg/End Y (km): ',ybeg,yend
      endif

      call setij

 1000 continue

      return
      end

C --------------------------------------------------------
      Subroutine setij

c --- TILESELECT    Version: 3.0      Level: 090402               

C Purpose:
C    Get I/J range for lat/lon selection
C
C Zhong-Xiang Wu
C 4/2/2009

      include 'tileselect.par'
      include 'tileselect.cm1'

      x1dmn=cfg(5)  ! coarse SW grid Xo
      y1dmn=cfg(6)  ! coarse SW grid Yo
      dxy=cfg(7)      ! fine grid size used as new 3D grid size

      fi1=(xbeg-x1dmn)/dxy+1
      fi2=(xend-x1dmn)/dxy+1
      fj1=(ybeg-y1dmn)/dxy+1
      fj2=(yend-y1dmn)/dxy+1

      i1=int(fi1)
      i2=int(fi2)
      j1=int(fj1)
      j2=int(fj2)

      if(float(i2).lt.fi2) i2=i2+1
      if(float(j2).lt.fj2) j2=j2+1

      ibeg=i1
      iend=i2
      jbeg=j1
      jend=j2

      write(ilog,330)ibeg,iend,jbeg,jend
      print 330,ibeg,iend,jbeg,jend
 330  format(' I/J ranges converted from Lon/Lat:',4i6)

C --- Adjust I/J beg/end
      if(ibeg.lt.nx1) then
         write(ilog,331)ibeg,nx1
         print 331,ibeg,nx1
 331     format(' Warning: Select I1 < NX1, adjusted to NX1:',2i5)
         ibeg=nx1
      endif
      if(iend.gt.nx2) then
         write(ilog,332)iend,nx2
         print 332,iend,nx2
 332     format(' Warning: Select I2 > NX2, adjusted to NX2:',2i5)
         iend=nx2
      endif

      if(jbeg.lt.ny1) then
         write(ilog,333)jbeg,ny1
         print 333,jbeg,ny1
 333     format(' Warning: Select J1 < NY1, adjusted to NY1:',2i5)
         jbeg=ny1
      endif

      if(jend.gt.ny2) then
         write(ilog,334)jend,ny2
         print 334,jend,ny2
 334     format(' Warning: Select J2 > NY2, adjusted to NY2:',2i5)
         jend=ny2
      endif

      nn1=ibeg*iend
      nn2=jbeg*jend
      if(nn1.lt.1 .or. nn2.lt.1) then
         write(ilog,336)nn1,nn2,ibeg,iend,jbeg,jend
         print 336,nn1,nn2,ibeg,iend,jbeg,jend
 336     format(' Error: At least one negative for I/J range:',/,6i10)
         stop
      endif

      nni=iend-ibeg+1
      nnj=jend-jbeg+1
      if(nni.lt.1 .or. nnj.lt.1) then
         write(ilog,335)nni,nnj,ibeg,iend,jbeg,jend
         print 335,nni,nnj,ibeg,iend,jbeg,jend
 335     format(' Error: No grid Selected:',6i6)
         stop
      endif

      return
      end

C --------------------------------------------------------------------
      Subroutine lastup(in,cvercfg,clvlcfg,lastupdate)

c --- TILESELECT    Version: V3.0       Level: 090929                 
c
c --- Purpose:
C     Get lastupdating date timestamp
c 
c --- Zhong-Xiang Wu
C     9/29/2009

      character*120 buff

      read(in,'(a)')buff

      read(buff,'(2a16)')cvercfg,clvlcfg
      nt=index(buff,':')+1
      read(buff(nt:),*)lastupdate
      
      return
      end
